.. _index:

Qpformat is a Python3 library for opening quantitative
phase imaging data file formats. This is the
documentation of qpformat version |release|.

Documentation
=============

.. toctree::
   :maxdepth: 4

   sec_introduction
   sec_getting_started
   sec_examples
   sec_code_reference

.. toctree::
   :maxdepth: 1

   sec_changelog
   sec_z_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
